@@ -3,8 +3,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-static const gchar *datapath;
-
 static GKeyFile *
 load_data (const gchar   *data,
            GKeyFileFlags  flags)
@@ -1311,7 +1309,7 @@ test_load (void)
   /* Uses the value of $XDG_DATA_HOME we set in main() */
   loaded = g_key_file_load_from_data_dirs (file, "keyfiletest.ini", NULL, 0, &error);
 #else
-  loaded = g_key_file_load_from_file (file, SRCDIR "/keyfiletest.ini", 0, &error);
+  loaded = g_key_file_load_from_file (file, g_test_get_filename (G_TEST_DIST, "keyfiletest.ini", NULL), 0, &error);
 #endif
   g_assert_no_error (error);
   g_assert (loaded);
@@ -1339,13 +1337,10 @@ test_load_fail (void)
 {
   GKeyFile *file;
   GError *error;
-  gchar *path;
 
   file = g_key_file_new ();
   error = NULL;
-  path = g_build_filename (datapath, "keyfile.c", NULL);
-  g_assert (!g_key_file_load_from_file (file, path, 0, &error));
-  g_free (path);
+  g_assert (!g_key_file_load_from_file (file, g_test_get_filename (G_TEST_DIST, "keyfile.c", NULL), 0, &error));
   g_assert_error (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_PARSE);
   g_clear_error (&error);
   g_assert (!g_key_file_load_from_file (file, "/nosuchfile", 0, &error));
@@ -1400,7 +1395,6 @@ test_page_boundary (void)
   GKeyFile *file;
   GError *error;
   gint i;
-  gchar *path;
 
 #define GROUP "main_section"
 #define KEY_PREFIX "fill_abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvw_"
@@ -1413,9 +1407,7 @@ test_page_boundary (void)
   file = g_key_file_new ();
 
   error = NULL;
-  path = g_build_filename (datapath, "pages.ini", NULL);
-  g_key_file_load_from_file (file, path, G_KEY_FILE_NONE, &error);
-  g_free (path);
+  g_key_file_load_from_file (file, g_test_get_filename (G_TEST_DIST, "pages.ini", NULL), G_KEY_FILE_NONE, &error);
   g_assert_no_error (error);
 
   for (i = FIRST_KEY; i <= LAST_KEY; i++)
@@ -1577,16 +1569,12 @@ test_roundtrip (void)
 int
 main (int argc, char *argv[])
 {
-  if (g_getenv ("G_TEST_DATA"))
-    datapath = g_getenv ("G_TEST_DATA");
-  else
-    datapath = SRCDIR;
+  g_test_init (&argc, &argv, NULL);
 
 #ifdef G_OS_UNIX
-  g_setenv ("XDG_DATA_HOME", datapath, TRUE);
+  g_setenv ("XDG_DATA_HOME", g_test_get_dir (G_TEST_DIST), TRUE);
 #endif
 
-  g_test_init (&argc, &argv, NULL);
   g_test_bug_base ("http://bugzilla.gnome.org/");
 
   g_test_add_func ("/keyfile/line-ends", test_line_ends);
